==> webkit2gtk_2.25.1.orig.tar.xz: webkitgtk-2.25.1/Source/WTF/wtf/fuchsia/CPUTimeFuchsia.cpp <==
/*
 * Copyright (C) 2018 Google, Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include <wtf/CPUTime.h>

#include <wtf/Optional.h>
#include <zircon/syscalls.h>

namespace WTF {

static Seconds timeToSeconds(zx_time_t t)
{
    return Seconds(t / static_cast<double>(ZX_SEC(1)));
}

Optional<CPUTime> CPUTime::get()
{
    // Fuchsia issue ZX-2318 tracks being able to get the monotonic and thread
    // times atomically and being able to separate ZX_CLOCK_THREAD into user and
    // kernel time.
    zx_time_t thread = zx_clock_get(ZX_CLOCK_THREAD);

    return CPUTime { MonotonicTime::now(), timeToSeconds(thread), Seconds() };
}

Seconds CPUTime::forCurrentThread()
{
    return timeToSeconds(zx_clock_get(ZX_CLOCK_THREAD));
}

}

==> webkit2gtk_2.30.3.orig.tar.xz: webkitgtk-2.30.3/Source/WTF/wtf/fuchsia/CPUTimeFuchsia.cpp <==
/*
 * Copyright (C) 2018 Google, Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include <wtf/CPUTime.h>

#include <wtf/Optional.h>
#include <zircon/syscalls.h>

namespace WTF {

static Seconds timeToSeconds(zx_time_t t)
{
    return Seconds(t / static_cast<double>(ZX_SEC(1)));
}

Optional<CPUTime> CPUTime::get()
{
    // Fuchsia issue ZX-2318 tracks being able to get the monotonic and thread
    // times atomically and being able to separate ZX_CLOCK_THREAD into user and
    // kernel time.
    zx_time_t thread = 0;
    zx_clock_get(ZX_CLOCK_THREAD, &thread);

    return CPUTime { MonotonicTime::now(), timeToSeconds(thread), Seconds() };
}

Seconds CPUTime::forCurrentThread()
{
    zx_time_t thread = 0;
    zx_clock_get(ZX_CLOCK_THREAD, &thread)
    return timeToSeconds(thread);
}

}
